@@ -37,17 +37,16 @@ except ImportError:
 import shutil
 
 # Import ioflo libs
-from ioflo.base.odicting import odict
-from ioflo.base.globaling import *
-
-from ioflo.base import aiding
-from ioflo.base import storing
+from ioflo.aid.odicting import odict
 from ioflo.base import deeding
 
 from ioflo.base.consoling import getConsole
 console = getConsole()
 
+# Import raet libs
+from ..abiding import *  # import globals
 from .. import raeting
+from ..raeting import AutoMode
 from ..road.stacking import  RoadStack
 from ..lane.stacking import  LaneStack
 from ..road import packeting, estating
@@ -96,7 +95,7 @@ class RaetRoadStack(deeding.Deed):
                                                  basedirpath='/tmp/raet/keep',
                                                  main=False,
                                                  mutable=True,
-                                                 auto=raeting.autoModes.once,
+                                                 auto=AutoMode.once.value,
                                                  uid=None,
                                                  host='0.0.0.0',
                                                  port=raeting.RAET_PORT,
@@ -157,7 +156,7 @@ class RaetRoadStackSetup(deeding.Deed):
                                                  basedirpath='/tmp/raet/keep',
                                                  main=False,
                                                  mutable=True,
-                                                 auto=raeting.autoModes.once,
+                                                 auto=AutoMode.once.value,
                                                  uid=None,
                                                  host='0.0.0.0',
                                                  port=raeting.RAET_PORT,
@@ -488,7 +487,7 @@ class RaetRoadStackPrinter(deeding.Deed):
 
     def action(self, **kwa):
         '''
-        Queue up message
+        Receive message
         '''
         rxMsgs = self.rxmsgs.value
         while rxMsgs:
@@ -656,15 +655,17 @@ class RaetLaneStackPrinter(deeding.Deed):
     '''
     Ioinits = odict(
         inode=".raet.lane.stack.",
+        total=odict(ipath="totalRxMsg", ival=odict(value=0)),
         stack="stack",
         rxmsgs=odict(ipath='rxmsgs', ival=deque()),)
 
     def action(self, **kwa):
         '''
-        Queue up message
+        Receive message
         '''
         rxMsgs = self.rxmsgs.value
         stack = self.stack.value
         while rxMsgs:
             msg, name = rxMsgs.popleft()
             console.terse("\n{0} Received....\n{1}\n".format(stack.name, msg))
+            self.total.value += 1
