@@ -22,10 +22,8 @@ except ImportError:
     mspack = None
 
 # Import ioflo libs
-from ioflo.base.odicting import odict
-from ioflo.base import aiding
+from ioflo.aid.odicting import odict
 from ioflo.base import nonblocking
-from ioflo.base import storing
 
 # Import raet libs
 from ..abiding import *  # import globals
@@ -93,6 +91,7 @@ class RoadStack(stacking.KeepStack):
     Interim = 3600 # stack default for reap timeout
     JoinerTimeout = 5.0 # stack default for joiner transaction timeout
     JoinentTimeout = 5.0 # stack default for joinent transaction timeout
+    MsgStaleTimeout = 600.0  # stale messages waiting timeout
 
     def __init__(self,
                  puid=None,
@@ -624,7 +623,8 @@ class RoadStack(stacking.KeepStack):
 
         if (packet.data['tk'] == TrnsKind.message and
                 packet.data['pk'] == PcktKind.message):
-            if packet.data['af']:  # packet is a stale resend
+            # transaction with this ID already handled and removed packet is a stale resend
+            if packet.data['af'] or packet.data['ti'] in remote.doneTransactions:
                 self.replyStale(packet, remote)
             else:
                 self.replyMessage(packet, remote)
